# -*- coding: utf-8 -*-
"""Init and utils."""

from zope.i18nmessageid import MessageFactory

_ = MessageFactory('collective.querynextprev')

QUERY = 'querynextprev.query'
SEARCH_URL = 'querynextprev.search_url'
PREVIOUS_UIDS = 'querynextprev.previous_uids'
NEXT_UIDS = 'querynextprev.next_uids'
